@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.54 2005/01/03 21:49:30 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.55 2005/01/12 20:05:26 richb Exp $
  *
  *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -456,7 +456,7 @@ paren_disp(char c)
  */
 
     n = strlen(v->display);
-    if (c == -1) {         /* Is it a Delete character? */
+    if (c == -1 || c == 127) {         /* Is it a Delete character? */
         v->noparens = v->pending = v->opsptr = v->numsptr = 0;
         v->cur_op = '?';
         i = 0;
