@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/mp.c,v 1.12 2004/07/19 17:41:04 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/mp.c,v 1.14 2004/11/03 22:50:20 richb Exp $
  *
  *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -935,27 +935,6 @@ L40:
 }
 
 
-void
-mpclr(int *x, int *n)
-{
-    int i__1;
-
-    static int i, i2, i3;
-
-/*  SETS X(T+3), ... , X(N+2) TO ZERO, USEFUL
- *  IF PRECISION IS GOING TO BE INCREASED.
- */
-
-    --x;                 /* Parameter adjustments */
-
-    if (*n <= MP.t) return;
-    i2 = MP.t + 3;
-    i3 = *n + 2;
-    i__1 = i3;
-    for (i = i2; i <= i__1; ++i) x[i] = 0;
-}
-
-
 void
 mpcmd(int *x, double *dz)
 {
@@ -3367,10 +3346,7 @@ mppwr2(int *x, int *y, int *z)
     else goto L70;
 
 L10:
-    if (v->MPerrors) {
-        FPRINTF(stderr, "*** X NEGATIVE IN CALL TO MPPWR2 ***\n");
-    }
-
+    show_error(_("Negative X and non-integer Y not supported"));
     goto L50;
 
 /* HERE X IS ZERO, RETURN ZERO IF Y POSITIVE, OTHERWISE ERROR */
